@@ -6,7 +6,6 @@ import re
 import sys
 import time
 from copy import deepcopy
-from enum import Enum, auto
 from pathlib import Path
 from urllib.parse import urlsplit
 
@@ -15,106 +14,83 @@ from aiohttp import ClientSession, TCPConnector
 
 from .config.operations import operations
 from .config.log_config import log_config
+from .constants import Operation
 from .login import Session
 from .utils import find_key, build_query, get_headers
 
 try:
     if get_ipython().__class__.__name__ == 'ZMQInteractiveShell':
         import nest_asyncio
-
         nest_asyncio.apply()
 except:
     ...
 
 if sys.platform != 'win32':
     import uvloop
-
     asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
 else:
     asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
 
-
-class Operation(Enum):
-    # tweet operations
-    TweetDetail = auto()
-    TweetResultByRestId = auto()
-    Favoriters = auto()
-    Retweeters = auto()
-
-    # user operations
-    Following = auto()
-    UserTweets = auto()
-    Followers = auto()
-    UserTweetsAndReplies = auto()
-    UserMedia = auto()
-    Likes = auto()
-    UserByScreenName = auto()
-    UserByRestId = auto()
-
-    # batch user operations
-    UsersByRestIds = auto()
-
-
 ID = 'ID'
 DUP_LIMIT = 5
 logging.config.dictConfig(log_config)
 logger = logging.getLogger(__name__)
 
 
-def get_user_tweets(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.UserTweets.name, 'userId', ids, session, limit)
+def get_user_tweets(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.UserTweets, 'userId', limit)
 
 
-def get_tweets_and_replies(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.UserTweetsAndReplies.name, 'userId', ids, session, limit)
+def get_tweets_and_replies(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.UserTweetsAndReplies, 'userId', limit)
 
 
-def get_likes(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.Likes.name, 'userId', ids, session, limit)
+def get_likes(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.Likes, 'userId', limit)
 
 
-def get_media(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.UserMedia.name, 'userId', ids, session, limit)
+def get_media(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.UserMedia, 'userId', limit)
 
 
-def get_followers(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.Followers.name, 'userId', ids, session, limit)
+def get_followers(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.Followers, 'userId', limit)
 
 
-def get_following(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.Following.name, 'userId', ids, session, limit)
+def get_following(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.Following, 'userId', limit)
 
 
-def get_favoriters(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.Favoriters.name, 'tweetId', ids, session, limit)
+def get_favoriters(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.Favoriters, 'tweetId', limit)
 
 
-def get_retweeters(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.Retweeters.name, 'tweetId', ids, session, limit)
+def get_retweeters(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.Retweeters, 'tweetId', limit)
 
 
-def get_tweets(ids: list[int], session: Session, limit=math.inf):
-    return run(Operation.TweetDetail.name, 'focalTweetId', ids, session, limit)
+def get_tweets(session: Session, ids: list[int], limit=math.inf):
+    return run(session, ids, Operation.Data.TweetDetail, 'focalTweetId', limit)
 
 
 # no pagination needed
-def get_tweet_by_rest_id(ids: list[int], session: Session):
-    return run(Operation.TweetResultByRestId.name, 'tweetId', ids, session)
+def get_tweet_by_rest_id(session: Session, ids: list[int]):
+    return run(session, ids, Operation.Data.TweetResultByRestId, 'tweetId')
 
 
 # no pagination needed
-def get_user_by_screen_name(ids: list[str], session: Session):
-    return run(Operation.UserByScreenName.name, 'screen_name', ids, session)
+def get_user_by_screen_name(session: Session, ids: list[str]):
+    return run(session, ids, Operation.Data.UserByScreenName, 'screen_name')
 
 
 # no pagination needed
-def get_user_by_rest_id(ids: list[int], session: Session):
-    return run(Operation.UserByRestId.name, 'userId', ids, session)
+def get_user_by_rest_id(session: Session, ids: list[int]):
+    return run(session, ids, Operation.Data.UserByRestId, 'userId')
 
 
 # no pagination needed (special batch query)
-def users_by_rest_ids(ids: list[int], session: Session):
-    operation = Operation.UsersByRestIds.name
+def users_by_rest_ids(session: Session, ids: list[int]):
+    operation = Operation.Data.UsersByRestIds
     qid = operations[operation]['queryId']
     params = deepcopy(operations[operation])
     params['variables']['userIds'] = ids
@@ -126,14 +102,14 @@ def users_by_rest_ids(ids: list[int], session: Session):
     return users
 
 
-def run(operation: str, key: str, ids: list[str | int], session: Session, limit=None):
-    res = graphql(ids, operation, key, session)
+def run(session: Session, ids: list[str | int], operation: str, key: str, limit=None):
+    res = graphql(session, ids, operation, key)
     if limit is None:
         return res
-    return asyncio.run(pagination(operation, key, res, session, limit))
+    return asyncio.run(pagination(session, res, operation, key, limit))
 
 
-def graphql(ids: list[any], operation: any, key: str | int, session: Session) -> list:
+def graphql(session: Session, ids: list[any], operation: any, key: str | int) -> list:
     qid = operations[operation]['queryId']
     params = deepcopy(operations[operation])
     urls = []
@@ -143,12 +119,12 @@ def graphql(ids: list[any], operation: any, key: str | int, session: Session) ->
         urls.append((_id, f"https://api.twitter.com/graphql/{qid}/{operation}?{query}"))
     headers = get_headers(session)
     headers['content-type'] = "application/json"
-    res = asyncio.run(process(urls, headers, session))
+    res = asyncio.run(process(session, urls, headers))
     save_data(res, operation)
     return res
 
 
-async def process(urls: list, headers: dict, session: Session) -> tuple:
+async def process(session: Session, urls: list, headers: dict) -> tuple:
     conn = TCPConnector(limit=0, ssl=False, ttl_dns_cache=69)
     async with ClientSession(headers=headers, connector=conn) as s:
         # add cookies from logged-in session
@@ -167,17 +143,17 @@ async def get(session: ClientSession, url: tuple) -> dict:
         logger.debug(e)
 
 
-async def pagination(operation: any, key: str, res: list, session: Session, limit) -> tuple:
+async def pagination(session: Session, res: list, operation: any, key: str, limit) -> tuple:
     conn = TCPConnector(limit=len(res), ssl=False, ttl_dns_cache=69)
     headers = get_headers(session)
     headers['content-type'] = "application/json"
     async with ClientSession(headers=headers, connector=conn) as s:
         # add cookies from logged-in session
         s.cookie_jar.update_cookies(session.cookies)
-        return await asyncio.gather(*(paginate(s, operation, key, data, limit) for data in res))
+        return await asyncio.gather(*(paginate(s, data, operation, key, limit) for data in res))
 
 
-async def paginate(session: ClientSession, operation: any, key: str, data: dict, limit: int):
+async def paginate(session: ClientSession, data: dict, operation: any, key: str, limit: int):
     def get_cursor(data):
         # inefficient, but need to deal with arbitrary schema
         entries = find_key(data, 'entries')
@@ -260,7 +236,7 @@ def save_data(data: list, operation: str = ''):
 
 def download(session: Session, post_url: str, cdn_url: str, path: str = 'media', chunk_size: int = 4096) -> None:
     """
-    Download media
+    Download file
 
     @param post_url: the actual post url
     @param cdn_url: the cdn url
@@ -280,8 +256,8 @@ def download(session: Session, post_url: str, cdn_url: str, path: str = 'media',
         logger.debug(f'FAILED to download video: {post_url} {e}')
 
 
-def download_media(ids: list[int], session: Session, photos: bool = True, videos: bool = True) -> None:
-    res = get_tweet_by_rest_id(ids, session=session)
+def download_media(session: Session, ids: list[int], photos: bool = True, videos: bool = True) -> None:
+    res = get_tweet_by_rest_id(session, ids)
     for r in res:
         user_id = find_key(r, 'user_results')[0]['result']['rest_id']
         url = f'https://twitter.com/{user_id}/status/{r[ID]}'  # evaluates to username in browser
