@@ -13,46 +13,7 @@ import aiohttp
 import requests
 
 from .config.log_config import log_config
-
-search_config = {
-    "include_profile_interstitial_type": 1,
-    "include_blocking": 1,
-    "include_blocked_by": 1,
-    "include_followed_by": 1,
-    "include_want_retweets": 1,
-    "include_mute_edge": 1,
-    "include_can_dm": 1,
-    "include_can_media_tag": 1,
-    "include_ext_has_nft_avatar": 1,
-    "include_ext_is_blue_verified": 1,
-    "include_ext_verified_type": 1,
-    "skip_status": 1,
-    "cards_platform": "Web-12",
-    "include_cards": 1,
-    "include_ext_alt_text": "true",
-    "include_ext_limited_action_results": "false",
-    "include_quote_count": "true",
-    "include_reply_count": 1,
-    "tweet_mode": "extended",
-    "include_ext_collab_control": "true",
-    "include_ext_views": "true",
-    "include_entities": "true",
-    "include_user_entities": "true",
-    "include_ext_media_color": "true",
-    "include_ext_media_availability": "true",
-    "include_ext_sensitive_media_warning": "true",
-    "include_ext_trusted_friends_metadata": "true",
-    "send_error_codes": "true",
-    "simple_quoted_tweet": "true",
-    "query_source": "typed_query",
-    "count": 100,
-    "q": "",
-    "requestContext": "launch",
-    "pc": 1,
-    "spelling_corrections": 1,
-    "include_ext_edit_control": "true",
-    "ext": "mediaStats,highlightedLabel,hasNftAvatar,voiceInfo,birdwatchPivot,enrichments,superFollowMetadata,unmentionInfo,editControl,collab_control,vibe"
-}
+from .config.settings import search_config
 
 IN_PATH = Path('~/data/raw').expanduser()
 OUT_PATH = Path(f'~/data/processed/search_results_{time.time_ns()}.json').expanduser()
