@@ -1,4 +1,4 @@
-from requests import Session
+import ujson
 
 
 def find_key(obj: dict | list[dict], key: str) -> list:
@@ -30,18 +30,25 @@ def find_key(obj: dict | list[dict], key: str) -> list:
     return helper(obj, key, [])
 
 
-def get_auth_headers(session: Session) -> dict:
+def get_headers(session) -> dict:
     """
     Get the headers required for authenticated requests
 
-    @param session: requests.Session object
+    @param session: special requests.Session object, modified during login process. contains attribute `tokens`
     @return: dict representing headers
     """
     return {
         'authorization': 'Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA',
-        'accept-encoding': 'gzip, deflate, br',
         'cookie': '; '.join(f'{k}={v}' for k, v in session.cookies.items()),
         'referer': 'https://twitter.com/',
         'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/110.0.0.0 Safari/537.36',
         'x-csrf-token': session.cookies.get('ct0'),
+        "x-guest-token": session.cookies.get('guest_token'),
+        "x-twitter-auth-type": "OAuth2Session" if session.cookies.get("auth_token") else '',
+        "x-twitter-active-user": "yes",
+        "x-twitter-client-language": 'en',
     }
+
+
+def build_query(params):
+    return '&'.join(f'{k}={ujson.dumps(v)}' for k, v in params.items())
